Method: SwaggerClient::MemoryInfo#initialize
- Defined in:
- lib/service/api/rapid7_insightvm_client/lib/swagger_client/models/memory_info.rb
#initialize(attributes = {}) ⇒ MemoryInfo
Initializes the object
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/service/api/rapid7_insightvm_client/lib/swagger_client/models/memory_info.rb', line 44 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SwaggerClient::MemoryInfo` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SwaggerClient::MemoryInfo`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'free') self.free = attributes[:'free'] end if attributes.key?(:'total') self.total = attributes[:'total'] end end |